
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "auto_examples/reliability_methods/plot_compute_reference_rp55_pf.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download_auto_examples_reliability_methods_plot_compute_reference_rp55_pf.py>`
        to download the full example code.

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_auto_examples_reliability_methods_plot_compute_reference_rp55_pf.py:


Compute reference probability for RP55
======================================

.. GENERATED FROM PYTHON SOURCE LINES 7-11

The goal of this example is to present how we computed the reference probability for problem 55 of the BBRC.
This calculation is based on the geometry of the failure domain.
In order to compute its surface, we use the `shapely` module,
which allows to compute the surface of bidimensional polygons.

.. GENERATED FROM PYTHON SOURCE LINES 13-19

.. code-block:: Python

    import openturns as ot
    import openturns.viewer as otv
    import numpy as np
    import otbenchmark as otb
    from shapely.geometry import Polygon








.. GENERATED FROM PYTHON SOURCE LINES 20-22

.. code-block:: Python

    problem = otb.ReliabilityProblem55()








.. GENERATED FROM PYTHON SOURCE LINES 23-26

.. code-block:: Python

    event = problem.getEvent()
    g = event.getFunction()








.. GENERATED FROM PYTHON SOURCE LINES 27-29

.. code-block:: Python

    problem.getProbability()





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.5600144282863704



.. GENERATED FROM PYTHON SOURCE LINES 30-32

Compute the bounds of the domain
--------------------------------

.. GENERATED FROM PYTHON SOURCE LINES 34-47

.. code-block:: Python

    inputVector = event.getAntecedent()
    distribution = inputVector.getDistribution()
    X1 = distribution.getMarginal(0)
    X2 = distribution.getMarginal(1)
    alphaMin = 0.00001
    alphaMax = 1 - alphaMin
    lowerBound = ot.Point(
        [X1.computeQuantile(alphaMin)[0], X2.computeQuantile(alphaMin)[0]]
    )
    upperBound = ot.Point(
        [X1.computeQuantile(alphaMax)[0], X2.computeQuantile(alphaMax)[0]]
    )








.. GENERATED FROM PYTHON SOURCE LINES 48-50

Print the iso-values of the distribution
----------------------------------------

.. GENERATED FROM PYTHON SOURCE LINES 52-57

.. code-block:: Python

    sampleSize = 5000
    sampleInput = inputVector.getSample(sampleSize)
    sampleOutput = g(sampleInput)
    drawEvent = otb.DrawEvent(event)








.. GENERATED FROM PYTHON SOURCE LINES 58-61

.. code-block:: Python

    cloud = drawEvent.drawSampleCrossCut(sampleSize)
    _ = otv.View(cloud)




.. image-sg:: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_001.png
   :alt: Points X s.t. g(X) < 0.0
   :srcset: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_001.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 62-64

Draw the limit state surface
----------------------------

.. GENERATED FROM PYTHON SOURCE LINES 66-69

.. code-block:: Python

    bounds = ot.Interval(lowerBound, upperBound)
    bounds






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Interval name=Unnamed dimension=2 lower bound=class=Point name=Unnamed dimension=2 values=[-0.99998,-0.99998] upper bound=class=Point name=Unnamed dimension=2 values=[0.99998,0.99998] finite lower bound=[1,1] finite upper bound=[1,1]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 70-73

.. code-block:: Python

    domain = drawEvent.fillEventCrossCut(bounds)
    _ = otv.View(domain)




.. image-sg:: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_002.png
   :alt: Domain where g(x) < 0.0
   :srcset: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_002.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 74-76

From integration
----------------

.. GENERATED FROM PYTHON SOURCE LINES 78-81

.. code-block:: Python

    interval = ot.Interval([-1.0, -1.0], [1.0, 1.0])
    interval






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Interval name=Unnamed dimension=2 lower bound=class=Point name=Unnamed dimension=2 values=[-1,-1] upper bound=class=Point name=Unnamed dimension=2 values=[1,1] finite lower bound=[1,1] finite upper bound=[1,1]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 82-85

.. code-block:: Python

    threshold = event.getThreshold()
    threshold





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.0



.. GENERATED FROM PYTHON SOURCE LINES 86-90

.. code-block:: Python

    mean = distribution.getMean()
    mean







.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Point name=Unnamed dimension=2 values=[0,0]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 91-108

.. code-block:: Python



    def ComputeIntegrandPoint(x):
        """Evaluate the integrand on one single point."""
        y = g(x)
        if y[0] < threshold:
            indicator = 1.0
        else:
            indicator = 0.0
        pdf = distribution.computePDF(x)
        z = [indicator * pdf]
        return z


    integrand = ot.PythonFunction(2, 1, ComputeIntegrandPoint)









.. GENERATED FROM PYTHON SOURCE LINES 109-112

.. code-block:: Python

    integrand(mean)







.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Point name=Unnamed dimension=1 values=[0]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 113-119

.. code-block:: Python

    dimension = distribution.getDimension()
    totalNumberOfPoints = 10 ** 4
    numberOfPointsInX = int(totalNumberOfPoints ** (1.0 / dimension))
    numberOfPointsInX






.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    100



.. GENERATED FROM PYTHON SOURCE LINES 120-125

.. code-block:: Python

    algoGL = ot.GaussLegendre([numberOfPointsInX] * dimension)
    value = algoGL.integrate(integrand, interval)
    value







.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Point name=Unnamed dimension=1 values=[0.558822]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 126-137

.. code-block:: Python



    def ComputeIntegrandSample(sample):
        """Evaluate the integrand on a sample."""
        indicatorBoolean = np.array(g(sample)) < threshold
        indicator = np.array(indicatorBoolean, float)
        pdf = np.array(distribution.computePDF(sample))
        z = indicator * pdf
        return z









.. GENERATED FROM PYTHON SOURCE LINES 138-141

.. code-block:: Python

    integrandSample = ot.PythonFunction(2, 1, func_sample=ComputeIntegrandSample)









.. GENERATED FROM PYTHON SOURCE LINES 142-145

.. code-block:: Python

    sample = distribution.getSample(5)
    integrandSample(sample)






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    <table>
      <tr><td></td><th>y0</th></tr>
      <tr><th>0</th><td>0</td></tr>
      <tr><th>1</th><td>0.25</td></tr>
      <tr><th>2</th><td>0</td></tr>
      <tr><th>3</th><td>0.25</td></tr>
      <tr><th>4</th><td>0.25</td></tr>
    </table>
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 146-148

.. code-block:: Python

    integrandSample(mean)






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Point name=Unnamed dimension=1 values=[0]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 149-154

.. code-block:: Python

    dimension = distribution.getDimension()
    totalNumberOfPoints = 10 ** 6
    numberOfPointsInX = int(totalNumberOfPoints ** (1.0 / dimension))
    numberOfPointsInX





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    1000



.. GENERATED FROM PYTHON SOURCE LINES 155-160

.. code-block:: Python

    discretization = [numberOfPointsInX] * dimension
    algoGL = ot.GaussLegendre(discretization)
    value = algoGL.integrate(integrandSample, interval)
    value






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    class=Point name=Unnamed dimension=1 values=[0.559983]
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 161-172

Exact computation
-----------------

We solve the exact equation:

https://www.wolframalpha.com/input/?i=solve+min%280.2+%2B+0.6+*+%28x+-+y%29%5E4+-+%28x+-+y%29+%2F+sqrt%282%29%2C+0.2+%2B+0.6+*+%28x+-+y%29%5E4+%2B+%28x+-+y%29+%2F+sqrt%282%29%2C+%28x+-+y%29+%2B+5+%2F+sqrt%282%29+-+2.2%2C+%28y+-+x%29+%2B+5+%2F+sqrt%282%29+-+2.2%29+%3D+0

```
solve (x - y) + 5 / sqrt(2) - 22/10 = 0
solve 2/10 + 6/10 * d^4 - d / sqrt(2)
```

.. GENERATED FROM PYTHON SOURCE LINES 174-177

.. code-block:: Python

    domain = drawEvent.fillEventCrossCut(bounds)
    _ = otv.View(domain)




.. image-sg:: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_003.png
   :alt: Domain where g(x) < 0.0
   :srcset: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_003.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 178-179

We first compute the exact equations defining the slanted lines at the limit state.

.. GENERATED FROM PYTHON SOURCE LINES 179-192

.. code-block:: Python

    palette = [
        "dodgerblue3",
        "darkorange1",
        "forestgreen",
        "firebrick3",
        "mediumpurple3",
        "lightsalmon4",
        "orchid",
        "gray50",
        "goldenrod3",
        "turquoise3",
    ]








.. GENERATED FROM PYTHON SOURCE LINES 193-194

The goal is to define the failure domain.

.. GENERATED FROM PYTHON SOURCE LINES 194-197

.. code-block:: Python

    root1 = 5.0 / np.sqrt(2.0) - 2.2
    root1





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    1.3355339059327371



.. GENERATED FROM PYTHON SOURCE LINES 198-201

.. code-block:: Python

    root2 = 0.2887406174573670970
    root2





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.2887406174573671



.. GENERATED FROM PYTHON SOURCE LINES 202-205

.. code-block:: Python

    root3 = 0.9370483776955247344172976
    root3





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.9370483776955247



.. GENERATED FROM PYTHON SOURCE LINES 206-213

.. code-block:: Python

    root2 = 0.2887406174573670970
    f1full = ot.SymbolicFunction(["x", "root2"], ["x-root2"])
    f1 = ot.ParametricFunction(f1full, [1], [root2])
    graph1 = f1.draw(root2 - 1.0, 1.0, 100)
    graph1.setColors([palette[0]])
    graph1.setLegends(["f1"])








.. GENERATED FROM PYTHON SOURCE LINES 214-220

.. code-block:: Python

    f2full = ot.SymbolicFunction(["x", "root3"], ["x-root3"])
    f2 = ot.ParametricFunction(f2full, [1], [root3])
    graph2 = f2.draw(root3 - 1.0, 1.0, 100)
    graph2.setColors([palette[1]])
    graph2.setLegends(["f2"])








.. GENERATED FROM PYTHON SOURCE LINES 221-227

.. code-block:: Python

    f3full = ot.SymbolicFunction(["x", "root1"], ["x-root1"])
    f3 = ot.ParametricFunction(f3full, [1], [root1])
    graph3 = f3.draw(root1 - 1.0, 1.0, 100)
    graph3.setColors([palette[2]])
    graph3.setLegends(["f3"])








.. GENERATED FROM PYTHON SOURCE LINES 228-234

.. code-block:: Python

    f4full = ot.SymbolicFunction(["x", "root2"], ["x+root2"])
    f4 = ot.ParametricFunction(f4full, [1], [root2])
    graph4 = f4.draw(-1.0, 1.0 - root2, 100)
    graph4.setColors([palette[3]])
    graph4.setLegends(["f4"])








.. GENERATED FROM PYTHON SOURCE LINES 235-241

.. code-block:: Python

    f5full = ot.SymbolicFunction(["x", "root3"], ["x+root3"])
    f5 = ot.ParametricFunction(f5full, [1], [root3])
    graph5 = f5.draw(-1.0, 1.0 - root3, 100)
    graph5.setColors([palette[4]])
    graph5.setLegends(["f5"])








.. GENERATED FROM PYTHON SOURCE LINES 242-248

.. code-block:: Python

    f6full = ot.SymbolicFunction(["x", "root1"], ["x+root1"])
    f6 = ot.ParametricFunction(f6full, [1], [root1])
    graph6 = f6.draw(-1.0, 1.0 - root1, 100)
    graph6.setColors([palette[5]])
    graph6.setLegends(["f6"])








.. GENERATED FROM PYTHON SOURCE LINES 249-257

.. code-block:: Python

    domain.add(graph1)
    domain.add(graph2)
    domain.add(graph3)
    domain.add(graph4)
    domain.add(graph5)
    domain.add(graph6)
    _ = otv.View(domain)




.. image-sg:: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_004.png
   :alt: Domain where g(x) < 0.0
   :srcset: /auto_examples/reliability_methods/images/sphx_glr_plot_compute_reference_rp55_pf_004.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 258-259

Then we set the corners of the polygons in the failure domain.

.. GENERATED FROM PYTHON SOURCE LINES 259-278

.. code-block:: Python

    data = [
        [-1.0, 1.0],
        [1.0, f1([1.0])[0]],
        [1.0, f2([1.0])[0]],
        [1.0, f3([1.0])[0]],
        [-1.0, f4([-1.0])[0]],
        [-1.0, f5([-1.0])[0]],
        [-1.0, f6([-1.0])[0]],
        [root1 - 1.0, -1.0],
        [root2 - 1.0, -1.0],
        [root3 - 1.0, -1.0],
        [1.0 - root1, 1.0],
        [1.0 - root2, 1.0],
        [1.0 - root3, 1.0],
        [1.0, -1.0],
    ]
    sample = ot.Sample(data)
    sample






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    <table>
      <tr><td></td><th>v0</th><th>v1</th></tr>
      <tr><th>0</th><td>-1</td><td>1</td></tr>
      <tr><th>1</th><td>1</td><td>0.7112594</td></tr>
      <tr><th>2</th><td>1</td><td>0.06295162</td></tr>
      <tr><th>3</th><td>1</td><td>-0.3355339</td></tr>
      <tr><th>4</th><td>-1</td><td>-0.7112594</td></tr>
      <tr><th>5</th><td>-1</td><td>-0.06295162</td></tr>
      <tr><th>6</th><td>-1</td><td>0.3355339</td></tr>
      <tr><th>7</th><td>0.3355339</td><td>-1</td></tr>
      <tr><th>8</th><td>-0.7112594</td><td>-1</td></tr>
      <tr><th>9</th><td>-0.06295162</td><td>-1</td></tr>
      <tr><th>10</th><td>-0.3355339</td><td>1</td></tr>
      <tr><th>11</th><td>0.7112594</td><td>1</td></tr>
      <tr><th>12</th><td>0.06295162</td><td>1</td></tr>
      <tr><th>13</th><td>1</td><td>-1</td></tr>
    </table>
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 279-285

.. code-block:: Python

    cloud = ot.Cloud(sample)
    domain.add(cloud)
    extendedBounds = ot.Interval([-1.5, -1.5], [2.0, 2.0])
    domain.setBoundingBox(extendedBounds)
    domain





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    class=Graph name=Domain where g(x) < 0.0 implementation=class=GraphImplementation name=Domain where g(x) < 0.0 title=Domain where g(x) < 0.0 xTitle=x1 yTitle=x2 axes=ON grid=ON legendposition=topright legendFontSize=10 drawables=[class=Drawable name=Unnamed implementation=class=PolygonArray name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=In data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=11352 dimension=2 data=[[-0.679986,-0.99998],[-0.639987,-0.99998],[-0.679986,-0.959981],...,[0.719986,0.99998],[0.679986,0.99998],[0.679986,0.99998]] color=blue isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1 vertices number=4 palette=[lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1],class=Drawable name=Unnamed implementation=class=PolygonArray name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=Out data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=8648 dimension=2 data=[[-0.99998,-0.99998],[-0.959981,-0.99998],[-0.99998,-0.959981],...,[0.99998,0.99998],[0.959981,0.99998],[0.959981,0.99998]] color=blue isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1 vertices number=4 palette=[darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1],class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f1 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-0.711259,-1],[-0.693974,-0.982715],[-0.676688,-0.965429],[-0.659403,-0.948144],[-0.642118,-0.930858],[-0.624832,-0.913573],[-0.607547,-0.896287],[-0.590261,-0.879002],[-0.572976,-0.861716],[-0.55569,-0.844431],[-0.538405,-0.827146],[-0.521119,-0.80986],[-0.503834,-0.792575],[-0.486549,-0.775289],[-0.469263,-0.758004],[-0.451978,-0.740718],[-0.434692,-0.723433],[-0.417407,-0.706147],[-0.400121,-0.688862],[-0.382836,-0.671576],[-0.36555,-0.654291],[-0.348265,-0.637006],[-0.33098,-0.61972],[-0.313694,-0.602435],[-0.296409,-0.585149],[-0.279123,-0.567864],[-0.261838,-0.550578],[-0.244552,-0.533293],[-0.227267,-0.516007],[-0.209981,-0.498722],[-0.192696,-0.481437],[-0.17541,-0.464151],[-0.158125,-0.446866],[-0.14084,-0.42958],[-0.123554,-0.412295],[-0.106269,-0.395009],[-0.0889832,-0.377724],[-0.0716978,-0.360438],[-0.0544123,-0.343153],[-0.0371269,-0.325868],[-0.0198415,-0.308582],[-0.002556,-0.291297],[0.0147294,-0.274011],[0.0320149,-0.256726],[0.0493003,-0.23944],[0.0665858,-0.222155],[0.0838712,-0.204869],[0.101157,-0.187584],[0.118442,-0.170298],[0.135728,-0.153013],[0.153013,-0.135728],[0.170298,-0.118442],[0.187584,-0.101157],[0.204869,-0.0838712],[0.222155,-0.0665858],[0.23944,-0.0493003],[0.256726,-0.0320149],[0.274011,-0.0147294],[0.291297,0.002556],[0.308582,0.0198415],[0.325868,0.0371269],[0.343153,0.0544123],[0.360438,0.0716978],[0.377724,0.0889832],[0.395009,0.106269],[0.412295,0.123554],[0.42958,0.14084],[0.446866,0.158125],[0.464151,0.17541],[0.481437,0.192696],[0.498722,0.209981],[0.516007,0.227267],[0.533293,0.244552],[0.550578,0.261838],[0.567864,0.279123],[0.585149,0.296409],[0.602435,0.313694],[0.61972,0.33098],[0.637006,0.348265],[0.654291,0.36555],[0.671576,0.382836],[0.688862,0.400121],[0.706147,0.417407],[0.723433,0.434692],[0.740718,0.451978],[0.758004,0.469263],[0.775289,0.486549],[0.792575,0.503834],[0.80986,0.521119],[0.827146,0.538405],[0.844431,0.55569],[0.861716,0.572976],[0.879002,0.590261],[0.896287,0.607547],[0.913573,0.624832],[0.930858,0.642118],[0.948144,0.659403],[0.965429,0.676688],[0.982715,0.693974],[1,0.711259]] color=dodgerblue3 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f2 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-0.0629516,-1],[-0.0522147,-0.989263],[-0.0414779,-0.978526],[-0.030741,-0.967789],[-0.0200041,-0.957052],[-0.0092672,-0.946316],[0.00146969,-0.935579],[0.0122066,-0.924842],[0.0229435,-0.914105],[0.0336803,-0.903368],[0.0444172,-0.892631],[0.0551541,-0.881894],[0.065891,-0.871157],[0.0766279,-0.86042],[0.0873648,-0.849684],[0.0981017,-0.838947],[0.108839,-0.82821],[0.119575,-0.817473],[0.130312,-0.806736],[0.141049,-0.795999],[0.151786,-0.785262],[0.162523,-0.774525],[0.17326,-0.763789],[0.183997,-0.753052],[0.194734,-0.742315],[0.205471,-0.731578],[0.216207,-0.720841],[0.226944,-0.710104],[0.237681,-0.699367],[0.248418,-0.68863],[0.259155,-0.677893],[0.269892,-0.667157],[0.280629,-0.65642],[0.291366,-0.645683],[0.302102,-0.634946],[0.312839,-0.624209],[0.323576,-0.613472],[0.334313,-0.602735],[0.34505,-0.591998],[0.355787,-0.581261],[0.366524,-0.570525],[0.377261,-0.559788],[0.387998,-0.549051],[0.398734,-0.538314],[0.409471,-0.527577],[0.420208,-0.51684],[0.430945,-0.506103],[0.441682,-0.495366],[0.452419,-0.48463],[0.463156,-0.473893],[0.473893,-0.463156],[0.48463,-0.452419],[0.495366,-0.441682],[0.506103,-0.430945],[0.51684,-0.420208],[0.527577,-0.409471],[0.538314,-0.398734],[0.549051,-0.387998],[0.559788,-0.377261],[0.570525,-0.366524],[0.581261,-0.355787],[0.591998,-0.34505],[0.602735,-0.334313],[0.613472,-0.323576],[0.624209,-0.312839],[0.634946,-0.302102],[0.645683,-0.291366],[0.65642,-0.280629],[0.667157,-0.269892],[0.677893,-0.259155],[0.68863,-0.248418],[0.699367,-0.237681],[0.710104,-0.226944],[0.720841,-0.216207],[0.731578,-0.205471],[0.742315,-0.194734],[0.753052,-0.183997],[0.763789,-0.17326],[0.774525,-0.162523],[0.785262,-0.151786],[0.795999,-0.141049],[0.806736,-0.130312],[0.817473,-0.119575],[0.82821,-0.108839],[0.838947,-0.0981017],[0.849684,-0.0873648],[0.86042,-0.0766279],[0.871157,-0.065891],[0.881894,-0.0551541],[0.892631,-0.0444172],[0.903368,-0.0336803],[0.914105,-0.0229435],[0.924842,-0.0122066],[0.935579,-0.00146969],[0.946316,0.0092672],[0.957052,0.0200041],[0.967789,0.030741],[0.978526,0.0414779],[0.989263,0.0522147],[1,0.0629516]] color=darkorange1 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f3 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[0.335534,-1],[0.342246,-0.993288],[0.348957,-0.986576],[0.355669,-0.979865],[0.362381,-0.973153],[0.369093,-0.966441],[0.375805,-0.959729],[0.382516,-0.953018],[0.389228,-0.946306],[0.39594,-0.939594],[0.402652,-0.932882],[0.409363,-0.92617],[0.416075,-0.919459],[0.422787,-0.912747],[0.429499,-0.906035],[0.436211,-0.899323],[0.442922,-0.892612],[0.449634,-0.8859],[0.456346,-0.879188],[0.463058,-0.872476],[0.469769,-0.865764],[0.476481,-0.859053],[0.483193,-0.852341],[0.489905,-0.845629],[0.496617,-0.838917],[0.503328,-0.832206],[0.51004,-0.825494],[0.516752,-0.818782],[0.523464,-0.81207],[0.530175,-0.805358],[0.536887,-0.798647],[0.543599,-0.791935],[0.550311,-0.785223],[0.557023,-0.778511],[0.563734,-0.7718],[0.570446,-0.765088],[0.577158,-0.758376],[0.58387,-0.751664],[0.590581,-0.744952],[0.597293,-0.738241],[0.604005,-0.731529],[0.610717,-0.724817],[0.617429,-0.718105],[0.62414,-0.711394],[0.630852,-0.704682],[0.637564,-0.69797],[0.644276,-0.691258],[0.650988,-0.684546],[0.657699,-0.677835],[0.664411,-0.671123],[0.671123,-0.664411],[0.677835,-0.657699],[0.684546,-0.650988],[0.691258,-0.644276],[0.69797,-0.637564],[0.704682,-0.630852],[0.711394,-0.62414],[0.718105,-0.617429],[0.724817,-0.610717],[0.731529,-0.604005],[0.738241,-0.597293],[0.744952,-0.590581],[0.751664,-0.58387],[0.758376,-0.577158],[0.765088,-0.570446],[0.7718,-0.563734],[0.778511,-0.557023],[0.785223,-0.550311],[0.791935,-0.543599],[0.798647,-0.536887],[0.805358,-0.530175],[0.81207,-0.523464],[0.818782,-0.516752],[0.825494,-0.51004],[0.832206,-0.503328],[0.838917,-0.496617],[0.845629,-0.489905],[0.852341,-0.483193],[0.859053,-0.476481],[0.865764,-0.469769],[0.872476,-0.463058],[0.879188,-0.456346],[0.8859,-0.449634],[0.892612,-0.442922],[0.899323,-0.436211],[0.906035,-0.429499],[0.912747,-0.422787],[0.919459,-0.416075],[0.92617,-0.409363],[0.932882,-0.402652],[0.939594,-0.39594],[0.946306,-0.389228],[0.953018,-0.382516],[0.959729,-0.375805],[0.966441,-0.369093],[0.973153,-0.362381],[0.979865,-0.355669],[0.986576,-0.348957],[0.993288,-0.342246],[1,-0.335534]] color=forestgreen isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f4 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-1,-0.711259],[-0.982715,-0.693974],[-0.965429,-0.676688],[-0.948144,-0.659403],[-0.930858,-0.642118],[-0.913573,-0.624832],[-0.896287,-0.607547],[-0.879002,-0.590261],[-0.861716,-0.572976],[-0.844431,-0.55569],[-0.827146,-0.538405],[-0.80986,-0.521119],[-0.792575,-0.503834],[-0.775289,-0.486549],[-0.758004,-0.469263],[-0.740718,-0.451978],[-0.723433,-0.434692],[-0.706147,-0.417407],[-0.688862,-0.400121],[-0.671576,-0.382836],[-0.654291,-0.36555],[-0.637006,-0.348265],[-0.61972,-0.33098],[-0.602435,-0.313694],[-0.585149,-0.296409],[-0.567864,-0.279123],[-0.550578,-0.261838],[-0.533293,-0.244552],[-0.516007,-0.227267],[-0.498722,-0.209981],[-0.481437,-0.192696],[-0.464151,-0.17541],[-0.446866,-0.158125],[-0.42958,-0.14084],[-0.412295,-0.123554],[-0.395009,-0.106269],[-0.377724,-0.0889832],[-0.360438,-0.0716978],[-0.343153,-0.0544123],[-0.325868,-0.0371269],[-0.308582,-0.0198415],[-0.291297,-0.002556],[-0.274011,0.0147294],[-0.256726,0.0320149],[-0.23944,0.0493003],[-0.222155,0.0665858],[-0.204869,0.0838712],[-0.187584,0.101157],[-0.170298,0.118442],[-0.153013,0.135728],[-0.135728,0.153013],[-0.118442,0.170298],[-0.101157,0.187584],[-0.0838712,0.204869],[-0.0665858,0.222155],[-0.0493003,0.23944],[-0.0320149,0.256726],[-0.0147294,0.274011],[0.002556,0.291297],[0.0198415,0.308582],[0.0371269,0.325868],[0.0544123,0.343153],[0.0716978,0.360438],[0.0889832,0.377724],[0.106269,0.395009],[0.123554,0.412295],[0.14084,0.42958],[0.158125,0.446866],[0.17541,0.464151],[0.192696,0.481437],[0.209981,0.498722],[0.227267,0.516007],[0.244552,0.533293],[0.261838,0.550578],[0.279123,0.567864],[0.296409,0.585149],[0.313694,0.602435],[0.33098,0.61972],[0.348265,0.637006],[0.36555,0.654291],[0.382836,0.671576],[0.400121,0.688862],[0.417407,0.706147],[0.434692,0.723433],[0.451978,0.740718],[0.469263,0.758004],[0.486549,0.775289],[0.503834,0.792575],[0.521119,0.80986],[0.538405,0.827146],[0.55569,0.844431],[0.572976,0.861716],[0.590261,0.879002],[0.607547,0.896287],[0.624832,0.913573],[0.642118,0.930858],[0.659403,0.948144],[0.676688,0.965429],[0.693974,0.982715],[0.711259,1]] color=firebrick3 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f5 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-1,-0.0629516],[-0.989263,-0.0522147],[-0.978526,-0.0414779],[-0.967789,-0.030741],[-0.957052,-0.0200041],[-0.946316,-0.0092672],[-0.935579,0.00146969],[-0.924842,0.0122066],[-0.914105,0.0229435],[-0.903368,0.0336803],[-0.892631,0.0444172],[-0.881894,0.0551541],[-0.871157,0.065891],[-0.86042,0.0766279],[-0.849684,0.0873648],[-0.838947,0.0981017],[-0.82821,0.108839],[-0.817473,0.119575],[-0.806736,0.130312],[-0.795999,0.141049],[-0.785262,0.151786],[-0.774525,0.162523],[-0.763789,0.17326],[-0.753052,0.183997],[-0.742315,0.194734],[-0.731578,0.205471],[-0.720841,0.216207],[-0.710104,0.226944],[-0.699367,0.237681],[-0.68863,0.248418],[-0.677893,0.259155],[-0.667157,0.269892],[-0.65642,0.280629],[-0.645683,0.291366],[-0.634946,0.302102],[-0.624209,0.312839],[-0.613472,0.323576],[-0.602735,0.334313],[-0.591998,0.34505],[-0.581261,0.355787],[-0.570525,0.366524],[-0.559788,0.377261],[-0.549051,0.387998],[-0.538314,0.398734],[-0.527577,0.409471],[-0.51684,0.420208],[-0.506103,0.430945],[-0.495366,0.441682],[-0.48463,0.452419],[-0.473893,0.463156],[-0.463156,0.473893],[-0.452419,0.48463],[-0.441682,0.495366],[-0.430945,0.506103],[-0.420208,0.51684],[-0.409471,0.527577],[-0.398734,0.538314],[-0.387998,0.549051],[-0.377261,0.559788],[-0.366524,0.570525],[-0.355787,0.581261],[-0.34505,0.591998],[-0.334313,0.602735],[-0.323576,0.613472],[-0.312839,0.624209],[-0.302102,0.634946],[-0.291366,0.645683],[-0.280629,0.65642],[-0.269892,0.667157],[-0.259155,0.677893],[-0.248418,0.68863],[-0.237681,0.699367],[-0.226944,0.710104],[-0.216207,0.720841],[-0.205471,0.731578],[-0.194734,0.742315],[-0.183997,0.753052],[-0.17326,0.763789],[-0.162523,0.774525],[-0.151786,0.785262],[-0.141049,0.795999],[-0.130312,0.806736],[-0.119575,0.817473],[-0.108839,0.82821],[-0.0981017,0.838947],[-0.0873648,0.849684],[-0.0766279,0.86042],[-0.065891,0.871157],[-0.0551541,0.881894],[-0.0444172,0.892631],[-0.0336803,0.903368],[-0.0229435,0.914105],[-0.0122066,0.924842],[-0.00146969,0.935579],[0.0092672,0.946316],[0.0200041,0.957052],[0.030741,0.967789],[0.0414779,0.978526],[0.0522147,0.989263],[0.0629516,1]] color=mediumpurple3 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f6 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-1,0.335534],[-0.993288,0.342246],[-0.986576,0.348957],[-0.979865,0.355669],[-0.973153,0.362381],[-0.966441,0.369093],[-0.959729,0.375805],[-0.953018,0.382516],[-0.946306,0.389228],[-0.939594,0.39594],[-0.932882,0.402652],[-0.92617,0.409363],[-0.919459,0.416075],[-0.912747,0.422787],[-0.906035,0.429499],[-0.899323,0.436211],[-0.892612,0.442922],[-0.8859,0.449634],[-0.879188,0.456346],[-0.872476,0.463058],[-0.865764,0.469769],[-0.859053,0.476481],[-0.852341,0.483193],[-0.845629,0.489905],[-0.838917,0.496617],[-0.832206,0.503328],[-0.825494,0.51004],[-0.818782,0.516752],[-0.81207,0.523464],[-0.805358,0.530175],[-0.798647,0.536887],[-0.791935,0.543599],[-0.785223,0.550311],[-0.778511,0.557023],[-0.7718,0.563734],[-0.765088,0.570446],[-0.758376,0.577158],[-0.751664,0.58387],[-0.744952,0.590581],[-0.738241,0.597293],[-0.731529,0.604005],[-0.724817,0.610717],[-0.718105,0.617429],[-0.711394,0.62414],[-0.704682,0.630852],[-0.69797,0.637564],[-0.691258,0.644276],[-0.684546,0.650988],[-0.677835,0.657699],[-0.671123,0.664411],[-0.664411,0.671123],[-0.657699,0.677835],[-0.650988,0.684546],[-0.644276,0.691258],[-0.637564,0.69797],[-0.630852,0.704682],[-0.62414,0.711394],[-0.617429,0.718105],[-0.610717,0.724817],[-0.604005,0.731529],[-0.597293,0.738241],[-0.590581,0.744952],[-0.58387,0.751664],[-0.577158,0.758376],[-0.570446,0.765088],[-0.563734,0.7718],[-0.557023,0.778511],[-0.550311,0.785223],[-0.543599,0.791935],[-0.536887,0.798647],[-0.530175,0.805358],[-0.523464,0.81207],[-0.516752,0.818782],[-0.51004,0.825494],[-0.503328,0.832206],[-0.496617,0.838917],[-0.489905,0.845629],[-0.483193,0.852341],[-0.476481,0.859053],[-0.469769,0.865764],[-0.463058,0.872476],[-0.456346,0.879188],[-0.449634,0.8859],[-0.442922,0.892612],[-0.436211,0.899323],[-0.429499,0.906035],[-0.422787,0.912747],[-0.416075,0.919459],[-0.409363,0.92617],[-0.402652,0.932882],[-0.39594,0.939594],[-0.389228,0.946306],[-0.382516,0.953018],[-0.375805,0.959729],[-0.369093,0.966441],[-0.362381,0.973153],[-0.355669,0.979865],[-0.348957,0.986576],[-0.342246,0.993288],[-0.335534,1]] color=lightsalmon4 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Cloud name=Unnamed derived from class=DrawableImplementation name=Unnamed legend= data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=14 dimension=2 data=[[-1,1],[1,0.711259],[1,0.0629516],[1,-0.335534],[-1,-0.711259],[-1,-0.0629516],[-1,0.335534],[0.335534,-1],[-0.711259,-1],[-0.0629516,-1],[-0.335534,1],[0.711259,1],[0.0629516,1],[1,-1]] color=#bcbd22 isColorExplicitlySet=false fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1]



.. GENERATED FROM PYTHON SOURCE LINES 286-287

In order to identify these points, we add the legends as text in the plot.

.. GENERATED FROM PYTHON SOURCE LINES 289-292

.. code-block:: Python

    texts = ["p" + str(i) for i in range(sample.getSize())]
    texts





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    ['p0', 'p1', 'p2', 'p3', 'p4', 'p5', 'p6', 'p7', 'p8', 'p9', 'p10', 'p11', 'p12', 'p13']



.. GENERATED FROM PYTHON SOURCE LINES 293-295

.. code-block:: Python

    text = ot.Text(sample, texts)








.. GENERATED FROM PYTHON SOURCE LINES 296-299

.. code-block:: Python

    domain.add(text)
    domain





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    class=Graph name=Domain where g(x) < 0.0 implementation=class=GraphImplementation name=Domain where g(x) < 0.0 title=Domain where g(x) < 0.0 xTitle=x1 yTitle=x2 axes=ON grid=ON legendposition=topright legendFontSize=10 drawables=[class=Drawable name=Unnamed implementation=class=PolygonArray name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=In data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=11352 dimension=2 data=[[-0.679986,-0.99998],[-0.639987,-0.99998],[-0.679986,-0.959981],...,[0.719986,0.99998],[0.679986,0.99998],[0.679986,0.99998]] color=blue isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1 vertices number=4 palette=[lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1,lightsalmon1],class=Drawable name=Unnamed implementation=class=PolygonArray name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=Out data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=8648 dimension=2 data=[[-0.99998,-0.99998],[-0.959981,-0.99998],[-0.99998,-0.959981],...,[0.99998,0.99998],[0.959981,0.99998],[0.959981,0.99998]] color=blue isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1 vertices number=4 palette=[darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1,darkseagreen1],class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f1 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-0.711259,-1],[-0.693974,-0.982715],[-0.676688,-0.965429],[-0.659403,-0.948144],[-0.642118,-0.930858],[-0.624832,-0.913573],[-0.607547,-0.896287],[-0.590261,-0.879002],[-0.572976,-0.861716],[-0.55569,-0.844431],[-0.538405,-0.827146],[-0.521119,-0.80986],[-0.503834,-0.792575],[-0.486549,-0.775289],[-0.469263,-0.758004],[-0.451978,-0.740718],[-0.434692,-0.723433],[-0.417407,-0.706147],[-0.400121,-0.688862],[-0.382836,-0.671576],[-0.36555,-0.654291],[-0.348265,-0.637006],[-0.33098,-0.61972],[-0.313694,-0.602435],[-0.296409,-0.585149],[-0.279123,-0.567864],[-0.261838,-0.550578],[-0.244552,-0.533293],[-0.227267,-0.516007],[-0.209981,-0.498722],[-0.192696,-0.481437],[-0.17541,-0.464151],[-0.158125,-0.446866],[-0.14084,-0.42958],[-0.123554,-0.412295],[-0.106269,-0.395009],[-0.0889832,-0.377724],[-0.0716978,-0.360438],[-0.0544123,-0.343153],[-0.0371269,-0.325868],[-0.0198415,-0.308582],[-0.002556,-0.291297],[0.0147294,-0.274011],[0.0320149,-0.256726],[0.0493003,-0.23944],[0.0665858,-0.222155],[0.0838712,-0.204869],[0.101157,-0.187584],[0.118442,-0.170298],[0.135728,-0.153013],[0.153013,-0.135728],[0.170298,-0.118442],[0.187584,-0.101157],[0.204869,-0.0838712],[0.222155,-0.0665858],[0.23944,-0.0493003],[0.256726,-0.0320149],[0.274011,-0.0147294],[0.291297,0.002556],[0.308582,0.0198415],[0.325868,0.0371269],[0.343153,0.0544123],[0.360438,0.0716978],[0.377724,0.0889832],[0.395009,0.106269],[0.412295,0.123554],[0.42958,0.14084],[0.446866,0.158125],[0.464151,0.17541],[0.481437,0.192696],[0.498722,0.209981],[0.516007,0.227267],[0.533293,0.244552],[0.550578,0.261838],[0.567864,0.279123],[0.585149,0.296409],[0.602435,0.313694],[0.61972,0.33098],[0.637006,0.348265],[0.654291,0.36555],[0.671576,0.382836],[0.688862,0.400121],[0.706147,0.417407],[0.723433,0.434692],[0.740718,0.451978],[0.758004,0.469263],[0.775289,0.486549],[0.792575,0.503834],[0.80986,0.521119],[0.827146,0.538405],[0.844431,0.55569],[0.861716,0.572976],[0.879002,0.590261],[0.896287,0.607547],[0.913573,0.624832],[0.930858,0.642118],[0.948144,0.659403],[0.965429,0.676688],[0.982715,0.693974],[1,0.711259]] color=dodgerblue3 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f2 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-0.0629516,-1],[-0.0522147,-0.989263],[-0.0414779,-0.978526],[-0.030741,-0.967789],[-0.0200041,-0.957052],[-0.0092672,-0.946316],[0.00146969,-0.935579],[0.0122066,-0.924842],[0.0229435,-0.914105],[0.0336803,-0.903368],[0.0444172,-0.892631],[0.0551541,-0.881894],[0.065891,-0.871157],[0.0766279,-0.86042],[0.0873648,-0.849684],[0.0981017,-0.838947],[0.108839,-0.82821],[0.119575,-0.817473],[0.130312,-0.806736],[0.141049,-0.795999],[0.151786,-0.785262],[0.162523,-0.774525],[0.17326,-0.763789],[0.183997,-0.753052],[0.194734,-0.742315],[0.205471,-0.731578],[0.216207,-0.720841],[0.226944,-0.710104],[0.237681,-0.699367],[0.248418,-0.68863],[0.259155,-0.677893],[0.269892,-0.667157],[0.280629,-0.65642],[0.291366,-0.645683],[0.302102,-0.634946],[0.312839,-0.624209],[0.323576,-0.613472],[0.334313,-0.602735],[0.34505,-0.591998],[0.355787,-0.581261],[0.366524,-0.570525],[0.377261,-0.559788],[0.387998,-0.549051],[0.398734,-0.538314],[0.409471,-0.527577],[0.420208,-0.51684],[0.430945,-0.506103],[0.441682,-0.495366],[0.452419,-0.48463],[0.463156,-0.473893],[0.473893,-0.463156],[0.48463,-0.452419],[0.495366,-0.441682],[0.506103,-0.430945],[0.51684,-0.420208],[0.527577,-0.409471],[0.538314,-0.398734],[0.549051,-0.387998],[0.559788,-0.377261],[0.570525,-0.366524],[0.581261,-0.355787],[0.591998,-0.34505],[0.602735,-0.334313],[0.613472,-0.323576],[0.624209,-0.312839],[0.634946,-0.302102],[0.645683,-0.291366],[0.65642,-0.280629],[0.667157,-0.269892],[0.677893,-0.259155],[0.68863,-0.248418],[0.699367,-0.237681],[0.710104,-0.226944],[0.720841,-0.216207],[0.731578,-0.205471],[0.742315,-0.194734],[0.753052,-0.183997],[0.763789,-0.17326],[0.774525,-0.162523],[0.785262,-0.151786],[0.795999,-0.141049],[0.806736,-0.130312],[0.817473,-0.119575],[0.82821,-0.108839],[0.838947,-0.0981017],[0.849684,-0.0873648],[0.86042,-0.0766279],[0.871157,-0.065891],[0.881894,-0.0551541],[0.892631,-0.0444172],[0.903368,-0.0336803],[0.914105,-0.0229435],[0.924842,-0.0122066],[0.935579,-0.00146969],[0.946316,0.0092672],[0.957052,0.0200041],[0.967789,0.030741],[0.978526,0.0414779],[0.989263,0.0522147],[1,0.0629516]] color=darkorange1 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f3 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[0.335534,-1],[0.342246,-0.993288],[0.348957,-0.986576],[0.355669,-0.979865],[0.362381,-0.973153],[0.369093,-0.966441],[0.375805,-0.959729],[0.382516,-0.953018],[0.389228,-0.946306],[0.39594,-0.939594],[0.402652,-0.932882],[0.409363,-0.92617],[0.416075,-0.919459],[0.422787,-0.912747],[0.429499,-0.906035],[0.436211,-0.899323],[0.442922,-0.892612],[0.449634,-0.8859],[0.456346,-0.879188],[0.463058,-0.872476],[0.469769,-0.865764],[0.476481,-0.859053],[0.483193,-0.852341],[0.489905,-0.845629],[0.496617,-0.838917],[0.503328,-0.832206],[0.51004,-0.825494],[0.516752,-0.818782],[0.523464,-0.81207],[0.530175,-0.805358],[0.536887,-0.798647],[0.543599,-0.791935],[0.550311,-0.785223],[0.557023,-0.778511],[0.563734,-0.7718],[0.570446,-0.765088],[0.577158,-0.758376],[0.58387,-0.751664],[0.590581,-0.744952],[0.597293,-0.738241],[0.604005,-0.731529],[0.610717,-0.724817],[0.617429,-0.718105],[0.62414,-0.711394],[0.630852,-0.704682],[0.637564,-0.69797],[0.644276,-0.691258],[0.650988,-0.684546],[0.657699,-0.677835],[0.664411,-0.671123],[0.671123,-0.664411],[0.677835,-0.657699],[0.684546,-0.650988],[0.691258,-0.644276],[0.69797,-0.637564],[0.704682,-0.630852],[0.711394,-0.62414],[0.718105,-0.617429],[0.724817,-0.610717],[0.731529,-0.604005],[0.738241,-0.597293],[0.744952,-0.590581],[0.751664,-0.58387],[0.758376,-0.577158],[0.765088,-0.570446],[0.7718,-0.563734],[0.778511,-0.557023],[0.785223,-0.550311],[0.791935,-0.543599],[0.798647,-0.536887],[0.805358,-0.530175],[0.81207,-0.523464],[0.818782,-0.516752],[0.825494,-0.51004],[0.832206,-0.503328],[0.838917,-0.496617],[0.845629,-0.489905],[0.852341,-0.483193],[0.859053,-0.476481],[0.865764,-0.469769],[0.872476,-0.463058],[0.879188,-0.456346],[0.8859,-0.449634],[0.892612,-0.442922],[0.899323,-0.436211],[0.906035,-0.429499],[0.912747,-0.422787],[0.919459,-0.416075],[0.92617,-0.409363],[0.932882,-0.402652],[0.939594,-0.39594],[0.946306,-0.389228],[0.953018,-0.382516],[0.959729,-0.375805],[0.966441,-0.369093],[0.973153,-0.362381],[0.979865,-0.355669],[0.986576,-0.348957],[0.993288,-0.342246],[1,-0.335534]] color=forestgreen isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f4 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-1,-0.711259],[-0.982715,-0.693974],[-0.965429,-0.676688],[-0.948144,-0.659403],[-0.930858,-0.642118],[-0.913573,-0.624832],[-0.896287,-0.607547],[-0.879002,-0.590261],[-0.861716,-0.572976],[-0.844431,-0.55569],[-0.827146,-0.538405],[-0.80986,-0.521119],[-0.792575,-0.503834],[-0.775289,-0.486549],[-0.758004,-0.469263],[-0.740718,-0.451978],[-0.723433,-0.434692],[-0.706147,-0.417407],[-0.688862,-0.400121],[-0.671576,-0.382836],[-0.654291,-0.36555],[-0.637006,-0.348265],[-0.61972,-0.33098],[-0.602435,-0.313694],[-0.585149,-0.296409],[-0.567864,-0.279123],[-0.550578,-0.261838],[-0.533293,-0.244552],[-0.516007,-0.227267],[-0.498722,-0.209981],[-0.481437,-0.192696],[-0.464151,-0.17541],[-0.446866,-0.158125],[-0.42958,-0.14084],[-0.412295,-0.123554],[-0.395009,-0.106269],[-0.377724,-0.0889832],[-0.360438,-0.0716978],[-0.343153,-0.0544123],[-0.325868,-0.0371269],[-0.308582,-0.0198415],[-0.291297,-0.002556],[-0.274011,0.0147294],[-0.256726,0.0320149],[-0.23944,0.0493003],[-0.222155,0.0665858],[-0.204869,0.0838712],[-0.187584,0.101157],[-0.170298,0.118442],[-0.153013,0.135728],[-0.135728,0.153013],[-0.118442,0.170298],[-0.101157,0.187584],[-0.0838712,0.204869],[-0.0665858,0.222155],[-0.0493003,0.23944],[-0.0320149,0.256726],[-0.0147294,0.274011],[0.002556,0.291297],[0.0198415,0.308582],[0.0371269,0.325868],[0.0544123,0.343153],[0.0716978,0.360438],[0.0889832,0.377724],[0.106269,0.395009],[0.123554,0.412295],[0.14084,0.42958],[0.158125,0.446866],[0.17541,0.464151],[0.192696,0.481437],[0.209981,0.498722],[0.227267,0.516007],[0.244552,0.533293],[0.261838,0.550578],[0.279123,0.567864],[0.296409,0.585149],[0.313694,0.602435],[0.33098,0.61972],[0.348265,0.637006],[0.36555,0.654291],[0.382836,0.671576],[0.400121,0.688862],[0.417407,0.706147],[0.434692,0.723433],[0.451978,0.740718],[0.469263,0.758004],[0.486549,0.775289],[0.503834,0.792575],[0.521119,0.80986],[0.538405,0.827146],[0.55569,0.844431],[0.572976,0.861716],[0.590261,0.879002],[0.607547,0.896287],[0.624832,0.913573],[0.642118,0.930858],[0.659403,0.948144],[0.676688,0.965429],[0.693974,0.982715],[0.711259,1]] color=firebrick3 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f5 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-1,-0.0629516],[-0.989263,-0.0522147],[-0.978526,-0.0414779],[-0.967789,-0.030741],[-0.957052,-0.0200041],[-0.946316,-0.0092672],[-0.935579,0.00146969],[-0.924842,0.0122066],[-0.914105,0.0229435],[-0.903368,0.0336803],[-0.892631,0.0444172],[-0.881894,0.0551541],[-0.871157,0.065891],[-0.86042,0.0766279],[-0.849684,0.0873648],[-0.838947,0.0981017],[-0.82821,0.108839],[-0.817473,0.119575],[-0.806736,0.130312],[-0.795999,0.141049],[-0.785262,0.151786],[-0.774525,0.162523],[-0.763789,0.17326],[-0.753052,0.183997],[-0.742315,0.194734],[-0.731578,0.205471],[-0.720841,0.216207],[-0.710104,0.226944],[-0.699367,0.237681],[-0.68863,0.248418],[-0.677893,0.259155],[-0.667157,0.269892],[-0.65642,0.280629],[-0.645683,0.291366],[-0.634946,0.302102],[-0.624209,0.312839],[-0.613472,0.323576],[-0.602735,0.334313],[-0.591998,0.34505],[-0.581261,0.355787],[-0.570525,0.366524],[-0.559788,0.377261],[-0.549051,0.387998],[-0.538314,0.398734],[-0.527577,0.409471],[-0.51684,0.420208],[-0.506103,0.430945],[-0.495366,0.441682],[-0.48463,0.452419],[-0.473893,0.463156],[-0.463156,0.473893],[-0.452419,0.48463],[-0.441682,0.495366],[-0.430945,0.506103],[-0.420208,0.51684],[-0.409471,0.527577],[-0.398734,0.538314],[-0.387998,0.549051],[-0.377261,0.559788],[-0.366524,0.570525],[-0.355787,0.581261],[-0.34505,0.591998],[-0.334313,0.602735],[-0.323576,0.613472],[-0.312839,0.624209],[-0.302102,0.634946],[-0.291366,0.645683],[-0.280629,0.65642],[-0.269892,0.667157],[-0.259155,0.677893],[-0.248418,0.68863],[-0.237681,0.699367],[-0.226944,0.710104],[-0.216207,0.720841],[-0.205471,0.731578],[-0.194734,0.742315],[-0.183997,0.753052],[-0.17326,0.763789],[-0.162523,0.774525],[-0.151786,0.785262],[-0.141049,0.795999],[-0.130312,0.806736],[-0.119575,0.817473],[-0.108839,0.82821],[-0.0981017,0.838947],[-0.0873648,0.849684],[-0.0766279,0.86042],[-0.065891,0.871157],[-0.0551541,0.881894],[-0.0444172,0.892631],[-0.0336803,0.903368],[-0.0229435,0.914105],[-0.0122066,0.924842],[-0.00146969,0.935579],[0.0092672,0.946316],[0.0200041,0.957052],[0.030741,0.967789],[0.0414779,0.978526],[0.0522147,0.989263],[0.0629516,1]] color=mediumpurple3 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Curve name=Unnamed derived from class=DrawableImplementation name=Unnamed legend=f6 data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=100 dimension=2 data=[[-1,0.335534],[-0.993288,0.342246],[-0.986576,0.348957],[-0.979865,0.355669],[-0.973153,0.362381],[-0.966441,0.369093],[-0.959729,0.375805],[-0.953018,0.382516],[-0.946306,0.389228],[-0.939594,0.39594],[-0.932882,0.402652],[-0.92617,0.409363],[-0.919459,0.416075],[-0.912747,0.422787],[-0.906035,0.429499],[-0.899323,0.436211],[-0.892612,0.442922],[-0.8859,0.449634],[-0.879188,0.456346],[-0.872476,0.463058],[-0.865764,0.469769],[-0.859053,0.476481],[-0.852341,0.483193],[-0.845629,0.489905],[-0.838917,0.496617],[-0.832206,0.503328],[-0.825494,0.51004],[-0.818782,0.516752],[-0.81207,0.523464],[-0.805358,0.530175],[-0.798647,0.536887],[-0.791935,0.543599],[-0.785223,0.550311],[-0.778511,0.557023],[-0.7718,0.563734],[-0.765088,0.570446],[-0.758376,0.577158],[-0.751664,0.58387],[-0.744952,0.590581],[-0.738241,0.597293],[-0.731529,0.604005],[-0.724817,0.610717],[-0.718105,0.617429],[-0.711394,0.62414],[-0.704682,0.630852],[-0.69797,0.637564],[-0.691258,0.644276],[-0.684546,0.650988],[-0.677835,0.657699],[-0.671123,0.664411],[-0.664411,0.671123],[-0.657699,0.677835],[-0.650988,0.684546],[-0.644276,0.691258],[-0.637564,0.69797],[-0.630852,0.704682],[-0.62414,0.711394],[-0.617429,0.718105],[-0.610717,0.724817],[-0.604005,0.731529],[-0.597293,0.738241],[-0.590581,0.744952],[-0.58387,0.751664],[-0.577158,0.758376],[-0.570446,0.765088],[-0.563734,0.7718],[-0.557023,0.778511],[-0.550311,0.785223],[-0.543599,0.791935],[-0.536887,0.798647],[-0.530175,0.805358],[-0.523464,0.81207],[-0.516752,0.818782],[-0.51004,0.825494],[-0.503328,0.832206],[-0.496617,0.838917],[-0.489905,0.845629],[-0.483193,0.852341],[-0.476481,0.859053],[-0.469769,0.865764],[-0.463058,0.872476],[-0.456346,0.879188],[-0.449634,0.8859],[-0.442922,0.892612],[-0.436211,0.899323],[-0.429499,0.906035],[-0.422787,0.912747],[-0.416075,0.919459],[-0.409363,0.92617],[-0.402652,0.932882],[-0.39594,0.939594],[-0.389228,0.946306],[-0.382516,0.953018],[-0.375805,0.959729],[-0.369093,0.966441],[-0.362381,0.973153],[-0.355669,0.979865],[-0.348957,0.986576],[-0.342246,0.993288],[-0.335534,1]] color=lightsalmon4 isColorExplicitlySet=true fillStyle=solid lineStyle=solid pointStyle=none lineWidth=1,class=Drawable name=Unnamed implementation=class=Cloud name=Unnamed derived from class=DrawableImplementation name=Unnamed legend= data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=14 dimension=2 data=[[-1,1],[1,0.711259],[1,0.0629516],[1,-0.335534],[-1,-0.711259],[-1,-0.0629516],[-1,0.335534],[0.335534,-1],[-0.711259,-1],[-0.0629516,-1],[-0.335534,1],[0.711259,1],[0.0629516,1],[1,-1]] color=#bcbd22 isColorExplicitlySet=false fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1,class=Drawable name=Unnamed implementation=class=Text name=Unnamed derived from class=DrawableImplementation name=Unnamed legend= data=class=Sample name=Unnamed implementation=class=SampleImplementation name=Unnamed size=14 dimension=2 data=[[-1,1],[1,0.711259],[1,0.0629516],[1,-0.335534],[-1,-0.711259],[-1,-0.0629516],[-1,0.335534],[0.335534,-1],[-0.711259,-1],[-0.0629516,-1],[-0.335534,1],[0.711259,1],[0.0629516,1],[1,-1]] color=#17becf isColorExplicitlySet=false fillStyle=solid lineStyle=solid pointStyle=plus lineWidth=1]



.. GENERATED FROM PYTHON SOURCE LINES 300-303

The probability is the ratio between the failure domain and the domain itself.
The area of the domain is :math:`2^2`.
The area of each polygon is computed based on the shapely module.

.. GENERATED FROM PYTHON SOURCE LINES 303-306

.. code-block:: Python

    corners = np.array([sample[i] for i in [0, 6, 10]])
    corners





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    array([[-1.        ,  1.        ],
           [-1.        ,  0.33553391],
           [-0.33553391,  1.        ]])



.. GENERATED FROM PYTHON SOURCE LINES 307-311

.. code-block:: Python

    polygon = Polygon(corners)
    area1 = polygon.area
    area1





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.2207575950825023



.. GENERATED FROM PYTHON SOURCE LINES 312-318

.. code-block:: Python

    corners = np.array([sample[i] for i in [4, 11, 12, 5]])
    corners
    polygon = Polygon(corners)
    area2 = polygon.area
    area2





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.8992712614902384



.. GENERATED FROM PYTHON SOURCE LINES 319-325

.. code-block:: Python

    corners = np.array([sample[i] for i in [8, 9, 2, 1]])
    corners
    polygon = Polygon(corners)
    area3 = polygon.area
    area3





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.8992712614902386



.. GENERATED FROM PYTHON SOURCE LINES 326-332

.. code-block:: Python

    corners = np.array([sample[i] for i in [7, 13, 3]])
    corners
    polygon = Polygon(corners)
    area4 = polygon.area
    area4





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.2207575950825023



.. GENERATED FROM PYTHON SOURCE LINES 333-336

.. code-block:: Python

    pf = (area1 + area2 + area3 + area4) / 2.0 ** 2
    pf





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    0.5600144282863704



.. GENERATED FROM PYTHON SOURCE LINES 337-339

.. code-block:: Python

    print("pf=%.17e" % (pf))





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    pf=5.60014428286370380e-01




.. GENERATED FROM PYTHON SOURCE LINES 340-341

.. code-block:: Python

    otv.View.ShowAll()








.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (0 minutes 3.538 seconds)


.. _sphx_glr_download_auto_examples_reliability_methods_plot_compute_reference_rp55_pf.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: plot_compute_reference_rp55_pf.ipynb <plot_compute_reference_rp55_pf.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: plot_compute_reference_rp55_pf.py <plot_compute_reference_rp55_pf.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: plot_compute_reference_rp55_pf.zip <plot_compute_reference_rp55_pf.zip>`
